==> BashStyle-7.0a2.tar.bz2: bashstyle-ng/glade-xml/bashstyle7.glade.h <==
char *s = N_("		   GNU LESSER GENERAL PUBLIC LICENSE\n"
             "                       Version 3, 29 June 2007\n"
             "\n"
             " Copyright (C) 2007 Free Software Foundation, Inc. <http://fsf.org/>\n"
             " Everyone is permitted to copy and distribute verbatim copies\n"
             " of this license document, but changing it is not allowed.\n"
             "\n"
             "\n"
             "  This version of the GNU Lesser General Public License incorporates\n"
             "the terms and conditions of version 3 of the GNU General Public\n"
             "License, supplemented by the additional permissions listed below.\n"
             "\n"
             "  0. Additional Definitions.\n"
             "\n"
             "  As used herein, \"this License\" refers to version 3 of the GNU Lesser\n"
             "General Public License, and the \"GNU GPL\" refers to version 3 of the GNU\n"
             "General Public License.\n"
             "\n"
             "  \"The Library\" refers to a covered work governed by this License,\n"
             "other than an Application or a Combined Work as defined below.\n"
             "\n"
             "  An \"Application\" is any work that makes use of an interface provided\n"
             "by the Library, but which is not otherwise based on the Library.\n"
             "Defining a subclass of a class defined by the Library is deemed a mode\n"
             "of using an interface provided by the Library.\n"
             "\n"
             "  A \"Combined Work\" is a work produced by combining or linking an\n"
             "Application with the Library.  The particular version of the Library\n"
             "with which the Combined Work was made is also called the \"Linked\n"
             "Version\".\n"
             "\n"
             "  The \"Minimal Corresponding Source\" for a Combined Work means the\n"
             "Corresponding Source for the Combined Work, excluding any source code\n"
             "for portions of the Combined Work that, considered in isolation, are\n"
             "based on the Application, and not on the Linked Version.\n"
             "\n"
             "  The \"Corresponding Application Code\" for a Combined Work means the\n"
             "object code and/or source code for the Application, including any data\n"
             "and utility programs needed for reproducing the Combined Work from the\n"
             "Application, but excluding the System Libraries of the Combined Work.\n"
             "\n"
             "  1. Exception to Section 3 of the GNU GPL.\n"
             "\n"
             "  You may convey a covered work under sections 3 and 4 of this License\n"
             "without being bound by section 3 of the GNU GPL.\n"
             "\n"
             "  2. Conveying Modified Versions.\n"
             "\n"
             "  If you modify a copy of the Library, and, in your modifications, a\n"
             "facility refers to a function or data to be supplied by an Application\n"
             "that uses the facility (other than as an argument passed when the\n"
             "facility is invoked), then you may convey a copy of the modified\n"
             "version:\n"
             "\n"
             "   a) under this License, provided that you make a good faith effort to\n"
             "   ensure that, in the event an Application does not supply the\n"
             "   function or data, the facility still operates, and performs\n"
             "   whatever part of its purpose remains meaningful, or\n"
             "\n"
             "   b) under the GNU GPL, with none of the additional permissions of\n"
             "   this License applicable to that copy.\n"
             "\n"
             "  3. Object Code Incorporating Material from Library Header Files.\n"
             "\n"
             "  The object code form of an Application may incorporate material from\n"
             "a header file that is part of the Library.  You may convey such object\n"
             "code under terms of your choice, provided that, if the incorporated\n"
             "material is not limited to numerical parameters, data structure\n"
             "layouts and accessors, or small macros, inline functions and templates\n"
             "(ten or fewer lines in length), you do both of the following:\n"
             "\n"
             "   a) Give prominent notice with each copy of the object code that the\n"
             "   Library is used in it and that the Library and its use are\n"
             "   covered by this License.\n"
             "\n"
             "   b) Accompany the object code with a copy of the GNU GPL and this license\n"
             "   document.\n"
             "\n"
             "  4. Combined Works.\n"
             "\n"
             "  You may convey a Combined Work under terms of your choice that,\n"
             "taken together, effectively do not restrict modification of the\n"
             "portions of the Library contained in the Combined Work and reverse\n"
             "engineering for debugging such modifications, if you also do each of\n"
             "the following:\n"
             "\n"
             "   a) Give prominent notice with each copy of the Combined Work that\n"
             "   the Library is used in it and that the Library and its use are\n"
             "   covered by this License.\n"
             "\n"
             "   b) Accompany the Combined Work with a copy of the GNU GPL and this license\n"
             "   document.\n"
             "\n"
             "   c) For a Combined Work that displays copyright notices during\n"
             "   execution, include the copyright notice for the Library among\n"
             "   these notices, as well as a reference directing the user to the\n"
             "   copies of the GNU GPL and this license document.\n"
             "\n"
             "   d) Do one of the following:\n"
             "\n"
             "       0) Convey the Minimal Corresponding Source under the terms of this\n"
             "       License, and the Corresponding Application Code in a form\n"
             "       suitable for, and under terms that permit, the user to\n"
             "       recombine or relink the Application with a modified version of\n"
             "       the Linked Version to produce a modified Combined Work, in the\n"
             "       manner specified by section 6 of the GNU GPL for conveying\n"
             "       Corresponding Source.\n"
             "\n"
             "       1) Use a suitable shared library mechanism for linking with the\n"
             "       Library.  A suitable mechanism is one that (a) uses at run time\n"
             "       a copy of the Library already present on the user's computer\n"
             "       system, and (b) will operate properly with a modified version\n"
             "       of the Library that is interface-compatible with the Linked\n"
             "       Version.\n"
             "\n"
             "   e) Provide Installation Information, but only if you would otherwise\n"
             "   be required to provide such information under section 6 of the\n"
             "   GNU GPL, and only to the extent that such information is\n"
             "   necessary to install and execute a modified version of the\n"
             "   Combined Work produced by recombining or relinking the\n"
             "   Application with a modified version of the Linked Version. (If\n"
             "   you use option 4d0, the Installation Information must accompany\n"
             "   the Minimal Corresponding Source and Corresponding Application\n"
             "   Code. If you use option 4d1, you must provide the Installation\n"
             "   Information in the manner specified by section 6 of the GNU GPL\n"
             "   for conveying Corresponding Source.)\n"
             "\n"
             "  5. Combined Libraries.\n"
             "\n"
             "  You may place library facilities that are a work based on the\n"
             "Library side by side in a single library together with other library\n"
             "facilities that are not Applications and are not covered by this\n"
             "License, and convey such a combined library under terms of your\n"
             "choice, if you do both of the following:\n"
             "\n"
             "   a) Accompany the combined library with a copy of the same work based\n"
             "   on the Library, uncombined with any other library facilities,\n"
             "   conveyed under the terms of this License.\n"
             "\n"
             "   b) Give prominent notice with the combined library that part of it\n"
             "   is a work based on the Library, and explaining where to find the\n"
             "   accompanying uncombined form of the same work.\n"
             "\n"
             "  6. Revised Versions of the GNU Lesser General Public License.\n"
             "\n"
             "  The Free Software Foundation may publish revised and/or new versions\n"
             "of the GNU Lesser General Public License from time to time. Such new\n"
             "versions will be similar in spirit to the present version, but may\n"
             "differ in detail to address new problems or concerns.\n"
             "\n"
             "  Each version is given a distinguishing version number. If the\n"
             "Library as you received it specifies that a certain numbered version\n"
             "of the GNU Lesser General Public License \"or any later version\"\n"
             "applies to it, you have the option of following the terms and\n"
             "conditions either of that published version or of any later version\n"
             "published by the Free Software Foundation. If the Library as you\n"
             "received it does not specify a version number of the GNU Lesser\n"
             "General Public License, you may choose any version of the GNU Lesser\n"
             "General Public License ever published by the Free Software Foundation.\n"
             "\n"
             "  If the Library as you received it specifies that a proxy can decide\n"
             "whether future versions of the GNU Lesser General Public License shall\n"
             "apply, that proxy's public statement of acceptance of any version is\n"
             "permanent authorization for you to choose that version for the\n"
             "Library.");
char *s = N_("$ (# if root)");
char *s = N_("(c) 2007 - 2008 Christopher Bratusek");
char *s = N_("<b>Alias #1</b>");
char *s = N_("<b>Alias #2</b>");
char *s = N_("<b>Alias #3</b>");
char *s = N_("<b>Alias #4</b>");
char *s = N_("<b>Alias #5</b>");
char *s = N_("<b>Alias #6</b>");
char *s = N_("<b>Alias #7</b>");
char *s = N_("<b>BashStyle-NG Stuff</b>");
char *s = N_("<b>Basic</b>");
char *s = N_("<b>Colors</b>");
char *s = N_("<b>Completion</b>");
char *s = N_("<b>Custom Prompt</b>");
char *s = N_("<b>Export Profile</b>");
char *s = N_("<b>History</b>");
char *s = N_("<b>Import Profile</b>");
char *s = N_("<b>Misc</b>");
char *s = N_("<b>NX-RC</b>");
char *s = N_("<b>PROMPT_COMMAND</b>");
char *s = N_("<b>PS1</b>");
char *s = N_("<b>Preview</b>");
char *s = N_("<b>Separator Style</b>");
char *s = N_("<b>Standard Stuff</b>");
char *s = N_("<b>Style</b>");
char *s = N_("<b>TruncPWD</b>");
char *s = N_("<b>Tweaks</b>");
char *s = N_("About BashStyle-NG");
char *s = N_("BS-NG-Parse-Echo");
char *s = N_("Background Processes");
char *s = N_("Base Workdir");
char *s = N_("BashStyle-NG 6.9");
char *s = N_("Battery Load");
char *s = N_("CPU Load");
char *s = N_("Change Bellstyle:\n"
             "Audible\n"
             "Visible\n"
             "None");
char *s = N_("Change CDPATH");
char *s = N_("Change Color Style:\n"
             "Normal\n"
             "Bright\n"
             "Dimmed\n"
             "Inverted\n"
             "Underlined");
char *s = N_("Change Color to:\n"
             "Black\n"
             "Red\n"
             "Green\n"
             "Yellow\n"
             "Blue\n"
             "Magenta\n"
             "Cyan\n"
             "White\n"
             "Coldblue\n"
             "Smoothblue\n"
             "Iceblue\n"
             "Turqoise\n"
             "Smoothgreen");
char *s = N_("Change Completion Blacklist");
char *s = N_("Change editor for fc");
char *s = N_("Choose Color to Change:\n"
             "Username\n"
             "Hostname\n"
             "Date\n"
             "Time\n"
             "Workdir\n"
             "Font\n"
             "Separator\n"
             "Uptime\n"
             "PS2 PS3 PS4");
char *s = N_("Choose Editing Mode:\n"
             "Emacs\n"
             "Vi");
char *s = N_("Choose Grep Color:\n"
             "Black\n"
             "Red\n"
             "Green\n"
             "Yellow\n"
             "Blue\n"
             "Magenta\n"
             "Cyan\n"
             "White\n"
             "Coldblue\n"
             "Smoothblue\n"
             "Iceblue\n"
             "Turqoise\n"
             "Smoothgreen");
char *s = N_("Choose Style to modify:\n"
             "Separator\n"
             "Vector\n"
             "Floating Clock\n"
             "Clock Advanced\n"
             "Dash\n"
             "Job\n"
             "Elite\n"
             "Power-User\n"
             "Dirks\n"
             "Minimal\n"
             "Dot.Prompt\n"
             "Bracket\n"
             "Sepa-NG\n"
             "Quirk\n"
             "Sputnik");
char *s = N_("Choose Style:\n"
             "Separator\n"
             "Vector\n"
             "Floating Clock\n"
             "Clock Advanced\n"
             "Dash\n"
             "Job\n"
             "Elite\n"
             "Power-User\n"
             "Dirks\n"
             "Minimal\n"
             "Dot.Prompt\n"
             "Bracket\n"
             "Sepa-NG\n"
             "Quirk\n"
             "Sputnik");
char *s = N_("Command Number [History]");
char *s = N_("Command Number [Session]");
char *s = N_("Current TTY");
char *s = N_("Date");
char *s = N_("Directory Indicator");
char *s = N_("Display Memory:\n"
             "Free Memory\n"
             "Used Memory\n"
             "Both\n"
             "None");
char *s = N_("Export Profile");
char *s = N_("Files Amount:\n"
             "Include Hidden Files\n"
             "Exclude Hidden Files");
char *s = N_("Files Size");
char *s = N_("Full Hostname");
char *s = N_("Full Workdir");
char *s = N_("History Blacklist");
char *s = N_("History Control Type:\n"
             "Erasedups\n"
             "Ignoredups\n"
             "Ignorespace\n"
             "Ignoreboth");
char *s = N_("History Size");
char *s = N_("Hostname");
char *s = N_("Insert Symbolic Color:\n"
             "Username\n"
             "Hostname\n"
             "Date\n"
             "Time\n"
             "Workdir\n"
             "Font\n"
             "Separator\n"
             "Uptime\n"
             "PS2 PS3 PS4");
char *s = N_("Load Average:\n"
             "for 1 minute\n"
             "for 10 minutes\n"
             "for 15 minutes");
char *s = N_("Max PWD length");
char *s = N_("New Line");
char *s = N_("Number of Processes");
char *s = N_("PS2 PS3 and PS4");
char *s = N_("PWD cut char");
char *s = N_("Path");
char *s = N_("Reset Bash's History.");
char *s = N_("Restore an previously exported profile");
char *s = N_("Separator");
char *s = N_("Set Timeout (in seconds)");
/* xgettext:no-c-format */
char *s = N_("Show Diskspace:\n"
             "Used Space [MB]\n"
             "Free Space [MB]\n"
             "Used Space [%]\n"
             "Free Space [%]");
/* xgettext:no-c-format */
char *s = N_("Show Memory:\n"
             "Used Memory [MB]\n"
             "Free Memory [MB]\n"
             "Used Memory [%]\n"
             "Free Memory [%]");
char *s = N_("Terminfo for Manpages:\n"
             "Mostlike\n"
             "Mostlike-Bold");
char *s = N_("This will export your profile to ~/bashstyle/profile-[DATE]");
char *s = N_("Time");
char *s = N_("Trunced Workdir");
char *s = N_("Uptime");
char *s = N_("Username");
char *s = N_("Welcome Message");
char *s = N_("de_DE: Christopher Bratusek");
char *s = N_("http://www.nanolx.org");

==> BashStyle-7.3.tar.bz2: bashstyle-ng/glade-xml/bashstyle7.glade.h <==
char *s = N_("		   GNU LESSER GENERAL PUBLIC LICENSE\n"
             "                       Version 3, 29 June 2007\n"
             "\n"
             " Copyright (C) 2007 Free Software Foundation, Inc. <http://fsf.org/>\n"
             " Everyone is permitted to copy and distribute verbatim copies\n"
             " of this license document, but changing it is not allowed.\n"
             "\n"
             "\n"
             "  This version of the GNU Lesser General Public License incorporates\n"
             "the terms and conditions of version 3 of the GNU General Public\n"
             "License, supplemented by the additional permissions listed below.\n"
             "\n"
             "  0. Additional Definitions.\n"
             "\n"
             "  As used herein, \"this License\" refers to version 3 of the GNU Lesser\n"
             "General Public License, and the \"GNU GPL\" refers to version 3 of the GNU\n"
             "General Public License.\n"
             "\n"
             "  \"The Library\" refers to a covered work governed by this License,\n"
             "other than an Application or a Combined Work as defined below.\n"
             "\n"
             "  An \"Application\" is any work that makes use of an interface provided\n"
             "by the Library, but which is not otherwise based on the Library.\n"
             "Defining a subclass of a class defined by the Library is deemed a mode\n"
             "of using an interface provided by the Library.\n"
             "\n"
             "  A \"Combined Work\" is a work produced by combining or linking an\n"
             "Application with the Library.  The particular version of the Library\n"
             "with which the Combined Work was made is also called the \"Linked\n"
             "Version\".\n"
             "\n"
             "  The \"Minimal Corresponding Source\" for a Combined Work means the\n"
             "Corresponding Source for the Combined Work, excluding any source code\n"
             "for portions of the Combined Work that, considered in isolation, are\n"
             "based on the Application, and not on the Linked Version.\n"
             "\n"
             "  The \"Corresponding Application Code\" for a Combined Work means the\n"
             "object code and/or source code for the Application, including any data\n"
             "and utility programs needed for reproducing the Combined Work from the\n"
             "Application, but excluding the System Libraries of the Combined Work.\n"
             "\n"
             "  1. Exception to Section 3 of the GNU GPL.\n"
             "\n"
             "  You may convey a covered work under sections 3 and 4 of this License\n"
             "without being bound by section 3 of the GNU GPL.\n"
             "\n"
             "  2. Conveying Modified Versions.\n"
             "\n"
             "  If you modify a copy of the Library, and, in your modifications, a\n"
             "facility refers to a function or data to be supplied by an Application\n"
             "that uses the facility (other than as an argument passed when the\n"
             "facility is invoked), then you may convey a copy of the modified\n"
             "version:\n"
             "\n"
             "   a) under this License, provided that you make a good faith effort to\n"
             "   ensure that, in the event an Application does not supply the\n"
             "   function or data, the facility still operates, and performs\n"
             "   whatever part of its purpose remains meaningful, or\n"
             "\n"
             "   b) under the GNU GPL, with none of the additional permissions of\n"
             "   this License applicable to that copy.\n"
             "\n"
             "  3. Object Code Incorporating Material from Library Header Files.\n"
             "\n"
             "  The object code form of an Application may incorporate material from\n"
             "a header file that is part of the Library.  You may convey such object\n"
             "code under terms of your choice, provided that, if the incorporated\n"
             "material is not limited to numerical parameters, data structure\n"
             "layouts and accessors, or small macros, inline functions and templates\n"
             "(ten or fewer lines in length), you do both of the following:\n"
             "\n"
             "   a) Give prominent notice with each copy of the object code that the\n"
             "   Library is used in it and that the Library and its use are\n"
             "   covered by this License.\n"
             "\n"
             "   b) Accompany the object code with a copy of the GNU GPL and this license\n"
             "   document.\n"
             "\n"
             "  4. Combined Works.\n"
             "\n"
             "  You may convey a Combined Work under terms of your choice that,\n"
             "taken together, effectively do not restrict modification of the\n"
             "portions of the Library contained in the Combined Work and reverse\n"
             "engineering for debugging such modifications, if you also do each of\n"
             "the following:\n"
             "\n"
             "   a) Give prominent notice with each copy of the Combined Work that\n"
             "   the Library is used in it and that the Library and its use are\n"
             "   covered by this License.\n"
             "\n"
             "   b) Accompany the Combined Work with a copy of the GNU GPL and this license\n"
             "   document.\n"
             "\n"
             "   c) For a Combined Work that displays copyright notices during\n"
             "   execution, include the copyright notice for the Library among\n"
             "   these notices, as well as a reference directing the user to the\n"
             "   copies of the GNU GPL and this license document.\n"
             "\n"
             "   d) Do one of the following:\n"
             "\n"
             "       0) Convey the Minimal Corresponding Source under the terms of this\n"
             "       License, and the Corresponding Application Code in a form\n"
             "       suitable for, and under terms that permit, the user to\n"
             "       recombine or relink the Application with a modified version of\n"
             "       the Linked Version to produce a modified Combined Work, in the\n"
             "       manner specified by section 6 of the GNU GPL for conveying\n"
             "       Corresponding Source.\n"
             "\n"
             "       1) Use a suitable shared library mechanism for linking with the\n"
             "       Library.  A suitable mechanism is one that (a) uses at run time\n"
             "       a copy of the Library already present on the user's computer\n"
             "       system, and (b) will operate properly with a modified version\n"
             "       of the Library that is interface-compatible with the Linked\n"
             "       Version.\n"
             "\n"
             "   e) Provide Installation Information, but only if you would otherwise\n"
             "   be required to provide such information under section 6 of the\n"
             "   GNU GPL, and only to the extent that such information is\n"
             "   necessary to install and execute a modified version of the\n"
             "   Combined Work produced by recombining or relinking the\n"
             "   Application with a modified version of the Linked Version. (If\n"
             "   you use option 4d0, the Installation Information must accompany\n"
             "   the Minimal Corresponding Source and Corresponding Application\n"
             "   Code. If you use option 4d1, you must provide the Installation\n"
             "   Information in the manner specified by section 6 of the GNU GPL\n"
             "   for conveying Corresponding Source.)\n"
             "\n"
             "  5. Combined Libraries.\n"
             "\n"
             "  You may place library facilities that are a work based on the\n"
             "Library side by side in a single library together with other library\n"
             "facilities that are not Applications and are not covered by this\n"
             "License, and convey such a combined library under terms of your\n"
             "choice, if you do both of the following:\n"
             "\n"
             "   a) Accompany the combined library with a copy of the same work based\n"
             "   on the Library, uncombined with any other library facilities,\n"
             "   conveyed under the terms of this License.\n"
             "\n"
             "   b) Give prominent notice with the combined library that part of it\n"
             "   is a work based on the Library, and explaining where to find the\n"
             "   accompanying uncombined form of the same work.\n"
             "\n"
             "  6. Revised Versions of the GNU Lesser General Public License.\n"
             "\n"
             "  The Free Software Foundation may publish revised and/or new versions\n"
             "of the GNU Lesser General Public License from time to time. Such new\n"
             "versions will be similar in spirit to the present version, but may\n"
             "differ in detail to address new problems or concerns.\n"
             "\n"
             "  Each version is given a distinguishing version number. If the\n"
             "Library as you received it specifies that a certain numbered version\n"
             "of the GNU Lesser General Public License \"or any later version\"\n"
             "applies to it, you have the option of following the terms and\n"
             "conditions either of that published version or of any later version\n"
             "published by the Free Software Foundation. If the Library as you\n"
             "received it does not specify a version number of the GNU Lesser\n"
             "General Public License, you may choose any version of the GNU Lesser\n"
             "General Public License ever published by the Free Software Foundation.\n"
             "\n"
             "  If the Library as you received it specifies that a proxy can decide\n"
             "whether future versions of the GNU Lesser General Public License shall\n"
             "apply, that proxy's public statement of acceptance of any version is\n"
             "permanent authorization for you to choose that version for the\n"
             "Library.");
char *s = N_("$ (# if root)");
char *s = N_("(c) 2007 - 2008 Christopher Bratusek");
char *s = N_("<b>Alias #1</b>");
char *s = N_("<b>Alias #2</b>");
char *s = N_("<b>Alias #3</b>");
char *s = N_("<b>Alias #4</b>");
char *s = N_("<b>Alias #5</b>");
char *s = N_("<b>Alias #6</b>");
char *s = N_("<b>Alias #7</b>");
char *s = N_("<b>BashStyle-NG Stuff</b>");
char *s = N_("<b>Basic</b>");
char *s = N_("<b>Colors</b>");
char *s = N_("<b>Completion</b>");
char *s = N_("<b>Custom Prompt</b>");
char *s = N_("<b>Editing</b>");
char *s = N_("<b>Export Profile</b>");
char *s = N_("<b>Extras</b>");
char *s = N_("<b>History</b>");
char *s = N_("<b>Import Profile</b>");
char *s = N_("<b>Misc</b>");
char *s = N_("<b>NX-RC</b>");
char *s = N_("<b>PROMPT_COMMAND</b>");
char *s = N_("<b>PS1</b>");
char *s = N_("<b>Preview</b>");
char *s = N_("<b>Searching</b>");
char *s = N_("<b>Separator Style</b>");
char *s = N_("<b>Standard Stuff</b>");
char *s = N_("<b>Style</b>");
char *s = N_("<b>TruncPWD</b>");
char *s = N_("<b>Tweaks</b>");
char *s = N_("About BashStyle-NG");
char *s = N_("BS-NG-Parse-Echo");
char *s = N_("Background Processes");
char *s = N_("Base Workdir");
char *s = N_("BashStyle-NG 7.3");
char *s = N_("Battery Load");
char *s = N_("CPU Load");
char *s = N_("Change Bellstyle:\n"
             "Audible\n"
             "Visible\n"
             "None");
char *s = N_("Change CDPATH");
char *s = N_("Change Color Style:\n"
             "Normal\n"
             "Bright\n"
             "Dimmed\n"
             "Inverted\n"
             "Underlined");
char *s = N_("Change Color to:\n"
             "Black\n"
             "Red\n"
             "Green\n"
             "Yellow\n"
             "Blue\n"
             "Magenta\n"
             "Cyan\n"
             "White\n"
             "Coldblue\n"
             "Smoothblue\n"
             "Iceblue\n"
             "Turqoise\n"
             "Smoothgreen\n"
             "Winered\n"
             "Brown\n"
             "Silver\n"
             "Ocher\n"
             "Orange\n"
             "Purple\n"
             "Pink");
char *s = N_("Change Completion Blacklist");
char *s = N_("Change editor for fc");
char *s = N_("Choose Color to Change:\n"
             "Username\n"
             "Hostname\n"
             "Date\n"
             "Time\n"
             "Workdir\n"
             "Font\n"
             "Separator\n"
             "Uptime\n"
             "PS2 PS3 PS4");
char *s = N_("Choose Editing Mode:\n"
             "Emacs\n"
             "Vi");
char *s = N_("Choose Grep Color:\n"
             "Black\n"
             "Red\n"
             "Green\n"
             "Yellow\n"
             "Blue\n"
             "Magenta\n"
             "Cyan\n"
             "White\n"
             "Coldblue\n"
             "Smoothblue\n"
             "Iceblue\n"
             "Turqoise\n"
             "Smoothgreen");
char *s = N_("Choose Style to modify:\n"
             "Separator\n"
             "Vector\n"
             "Floating Clock\n"
             "Clock Advanced\n"
             "Dash\n"
             "Job\n"
             "Elite\n"
             "Power-User\n"
             "Dirks\n"
             "Minimal\n"
             "Dot.Prompt\n"
             "Bracket\n"
             "Sepa-NG\n"
             "Quirk\n"
             "Sputnik");
char *s = N_("Choose Style:\n"
             "Separator\n"
             "Vector\n"
             "Floating Clock\n"
             "Clock Advanced\n"
             "Dash\n"
             "Job\n"
             "Elite\n"
             "Power-User\n"
             "Dirks\n"
             "Minimal\n"
             "Dot.Prompt\n"
             "Bracket\n"
             "Sepa-NG\n"
             "Quirk\n"
             "Sputnik");
char *s = N_("Command Number [History]");
char *s = N_("Command Number [Session]");
char *s = N_("Current TTY");
char *s = N_("Date");
char *s = N_("Directory Indicator");
char *s = N_("Display Memory:\n"
             "Free Memory\n"
             "Used Memory\n"
             "Both\n"
             "None");
char *s = N_("Export Profile");
char *s = N_("Files Amount:\n"
             "Include Hidden Files\n"
             "Exclude Hidden Files");
char *s = N_("Files Size");
char *s = N_("Full Hostname");
char *s = N_("Full Workdir");
char *s = N_("History Blacklist");
char *s = N_("History Control Type:\n"
             "Erasedups\n"
             "Ignoredups\n"
             "Ignorespace\n"
             "Ignoreboth");
char *s = N_("History Size");
char *s = N_("Hostname");
char *s = N_("Insert Symbolic Color:\n"
             "Username\n"
             "Hostname\n"
             "Date\n"
             "Time\n"
             "Workdir\n"
             "Font\n"
             "Separator\n"
             "Uptime\n"
             "PS2 PS3 PS4");
char *s = N_("Load Average:\n"
             "for 1 minute\n"
             "for 10 minutes\n"
             "for 15 minutes");
char *s = N_("Max PWD length");
char *s = N_("New Line");
char *s = N_("Number of Processes");
char *s = N_("PS2 PS3 and PS4");
char *s = N_("PWD cut char");
char *s = N_("Path");
char *s = N_("Reset Bash's History.");
char *s = N_("Restore an previously exported profile");
char *s = N_("Separator");
char *s = N_("Set Timeout (in seconds)");
/* xgettext:no-c-format */
char *s = N_("Show Diskspace:\n"
             "Used Space [MB]\n"
             "Free Space [MB]\n"
             "Used Space [%]\n"
             "Free Space [%]");
/* xgettext:no-c-format */
char *s = N_("Show Memory:\n"
             "Used Memory [MB]\n"
             "Free Memory [MB]\n"
             "Used Memory [%]\n"
             "Free Memory [%]");
char *s = N_("Terminfo for Manpages:\n"
             "Mostlike\n"
             "Mostlike-Bold");
char *s = N_("This will export your profile to ~/bashstyle/profile-[DATE]");
char *s = N_("Time");
char *s = N_("Trunced Workdir");
char *s = N_("Uptime");
char *s = N_("Username");
char *s = N_("Welcome Message");
char *s = N_("de_DE: Christopher Bratusek\n"
             "it_IT: Alin Hantig");
char *s = N_("http://www.nanolx.org");
char *s = N_("rulerformat =");
